Crate testquorum_api

Crate testquorum_api 

TestQuorum API client library.

This crate provides a type-safe Rust interface to the TestQuorum API. All types and the client are generated from the OpenAPI specification using progenitor.

Modules

prelude
Items consumers will typically use such as the Client.
types
Types used as operation parameters and responses.

Structs

ByteStream
Untyped byte stream used for both success and error responses.
Client
Client for TestQuorum API
ResponseValue
Typed value returned by generated client methods.

Enums

Error
Error produced by generated client methods.

Traits

ClientInfo
Interface for which an implementation is generated for all clients.