pub struct Client { /* private fields */ }Expand description
Client for TestQuorum API
Version: 0.1.124
Implementations
Sourceimpl Client
impl Client
Sourcepub fn new(baseurl: &str, inner: Client) -> Self
pub fn new(baseurl: &str, inner: Client) -> Self
Create a new client.
baseurl is the base URL provided to the internal
reqwest::Client, and should include a scheme and hostname,
as well as port and a path stem if applicable.
Sourcepub fn new_with_client(baseurl: &str, client: Client, inner: Client) -> Self
pub fn new_with_client(baseurl: &str, client: Client, inner: Client) -> Self
Construct a new client with an existing reqwest::Client,
allowing more control over its configuration.
baseurl is the base URL provided to the internal
reqwest::Client, and should include a scheme and hostname,
as well as port and a path stem if applicable.
Sourceimpl Client
impl Client
Sourcepub async fn logout<'a>(&'a self) -> Result<ResponseValue<()>, Error<()>>
pub async fn logout<'a>(&'a self) -> Result<ResponseValue<()>, Error<()>>
Sends a POST request to /auth/logout
Sourcepub async fn session_info<'a>(
&'a self,
) -> Result<ResponseValue<SessionResponse>, Error<()>>
pub async fn session_info<'a>( &'a self, ) -> Result<ResponseValue<SessionResponse>, Error<()>>
Sends a GET request to /auth/session
Sourcepub async fn health<'a>(&'a self) -> Result<ResponseValue<()>, Error<()>>
pub async fn health<'a>(&'a self) -> Result<ResponseValue<()>, Error<()>>
Sends a GET request to /health/
Sourcepub async fn get_quote<'a>(
&'a self,
) -> Result<ResponseValue<QuoteResponse>, Error<()>>
pub async fn get_quote<'a>( &'a self, ) -> Result<ResponseValue<QuoteResponse>, Error<()>>
Sends a GET request to /quote/
Sourcepub async fn list_repos<'a>(
&'a self,
) -> Result<ResponseValue<Vec<RepoResponse>>, Error<()>>
pub async fn list_repos<'a>( &'a self, ) -> Result<ResponseValue<Vec<RepoResponse>>, Error<()>>
Sends a GET request to /repos/