pub struct QuoteResponse {
pub created_at: EpochSecs,
pub quote_id: String,
pub tiers: HashMap<String, TierPrices>,
pub valid_until: EpochSecs,
}Expand description
A pricing quote response containing subscription tiers and pricing information.
JSON schema
{
"description": "A pricing quote response containing subscription tiers and pricing information.",
"type": "object",
"required": [
"created_at",
"quote_id",
"tiers",
"valid_until"
],
"properties": {
"created_at": {
"$ref": "#/components/schemas/EpochSecs"
},
"quote_id": {
"type": "string"
},
"tiers": {
"type": "object",
"additionalProperties": {
"$ref": "#/components/schemas/TierPrices"
}
},
"valid_until": {
"$ref": "#/components/schemas/EpochSecs"
}
}
}Fields
created_at: EpochSecsquote_id: Stringtiers: HashMap<String, TierPrices>valid_until: EpochSecsTrait Implementations
Sourceimpl Clone for QuoteResponse
impl Clone for QuoteResponse
Sourcefn clone(&self) -> QuoteResponse
fn clone(&self) -> QuoteResponse
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for QuoteResponse
impl Debug for QuoteResponse
Sourceimpl<'de> Deserialize<'de> for QuoteResponse
impl<'de> Deserialize<'de> for QuoteResponse
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more